@@ -1,7 +1,7 @@
 #' Ideal-Gas part of the Dimensionless Helmholtz Energy Equation, Function of Temperature and Density
 #'
-#' @description The function \code{phi0(T,D)} returns the Ideal-gas part of the
-#'      dimensionless Helmholtz Energy Equation, phi0, for given T [K] and D [kg/m3].
+#' @description The function \code{phi0(Temp,D,digits=9)} returns the Ideal-gas part of the
+#'      dimensionless Helmholtz Energy Equation, phi0, for given Temp [K] and D [kg/m3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -10,36 +10,36 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
 #' @return The Ideal-gas part of the Helmholtz Energy Equation: phi0 and an Error
 #'      Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' phi_0 <- phi0(T,D)
+#' phi_0 <- phi0(Temp,D)
 #' phi_0
 #' 
 #' @export
 #' 
-  phi0 <- function(T,D) {
+  phi0 <- function(Temp,D,digits=9) {
   y <- 0.
   icode <- 0
-  res <- .Fortran('phi0TD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-  options(digits=9)
+  res <- .Fortran('phi0TD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
   if (res[[4]] != 0) { 
      error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
      print(error)
   }
-  return(res[[3]])
+  return(round(res[[3]],digits=digits))
   }
 
 #' First Derivative of the Ideal-Gas part of the Dimensionless Helmholtz Energy
 #'      Equation with respect to Density, Function of Density
 #'
-#' @description The function \code{phi0D(D)} returns the First Derivative of the
+#' @description The function \code{phi0D(D,digits=9)} returns the First Derivative of the
 #'     Ideal-gas part of the dimensionless Helmholtz Energy Equation for a given D [kg/m3]. 
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
@@ -49,7 +49,8 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param D Density [ kg m-3 ]  #' @param Opt: Option to not print the computed value (Opt = 0)
+#' @param D Density [ kg m-3 ]  
+#' @param digits Digits of results (optional)
 #' 
 #' @return The First D Derivative of Ideal-gas part of the Helmholtz Energy: phi0D and an Error
 #'      Message (if an error occur: \link{errorCodes})
@@ -61,22 +62,21 @@
 #'
 #' @export
 #' 
-  phi0D <- function(D) {
+  phi0D <- function(D,digits=9) {
   y <- 0.
   icode <- 0
   res <- .Fortran('phi0DD', as.double(D), as.double(y), as.integer(icode))
-  options(digits=9)
   if (res[[3]] != 0) { 
     error <-  as.character(errorCodes[which(errorCodes[,1]==res[[3]]),2])
     print(error)
   }
-  return(res[[2]])
+  return(round(res[[2]],digits=digits))
 } 
   
 #' Second Derivative of the Ideal-Gas Part of the Dimensionless Helmholtz Energy Equation
 #'     with respect to Density, Function of Density
 #'
-#' @description The function \code{phi0DD(D)} returns the Second Derivative of the
+#' @description The function \code{phi0DD(D,digits=9)} returns the Second Derivative of the
 #'     Ideal-gas part of the dimensionless Helmholtz Energy Equation for a given D [kg/m3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
@@ -87,6 +87,7 @@
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
 #' @return The Second D Derivative of Ideal-gas part of the Helmholtz Energy: phi0DD and an Error
 #'      Message (if an error occur: \link{errorCodes})
@@ -98,24 +99,23 @@
 #' 
 #' @export
 #' 
-  phi0DD <- function(D) {
+  phi0DD <- function(D,digits=9) {
     y <- 0.
     icode <- 0
     res <- .Fortran('phi0DDD', as.double(D), as.double(y), as.integer(icode))
-    options(digits=9)
     if (res[[3]] != 0) { 
       error <-  as.character(errorCodes[which(errorCodes[,1]==res[[3]]),2])
       print(error)
     }
-    return(res[[2]])
+    return(round(res[[2]],digits=digits))
   } 
   
 #' First Derivative of the Ideal-Gas Part of the Dimensionless Helmholtz Energy Equation
 #'     with respect to Temperature, Function of Temperature and Density
 #'
-#' @description The function \code{phi0T(T,D)} returns the First Derivative of the
+#' @description The function \code{phi0T(Temp,D,digits=9)} returns the First Derivative of the
 #'     Ideal-gas Part of the dimensionless Helmholtz Energy Equation with respect to 
-#'     Temperature, for given T [K] and D [kg/m3].
+#'     Temperature, for given Temp [K] and D [kg/m3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -124,38 +124,38 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
-#' @return The First T Derivative of Ideal-gas part of the Helmholtz Energy: phi0T and an Error
+#' @return The First Temp Derivative of Ideal-gas part of the Helmholtz Energy: phi0T and an Error
 #'      Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' phi0_T <- phi0T(T,D)
+#' phi0_T <- phi0T(Temp,D)
 #' phi0_T
 #' 
 #' @export
 #'  
-   phi0T <- function(T,D) {
+   phi0T <- function(Temp,D,digits=9) {
    y <- 0.
    icode <- 0
-   res <- .Fortran('phi0TTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-   options(digits=9)
+   res <- .Fortran('phi0TTD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
    if (res[[4]] != 0) { 
      error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
      print(error)
    }
-   return(res[[3]])
+   return(round(res[[3]],digits = digits))
  }
 
 #' Second Derivative of the Ideal-Gas Part of the Dimensionless Helmholtz Energy Equation
 #'     with respect to Temperature, Function of Temperature and Density
 #'
-#' @description The function \code{phi0TT(T,D)} returns the Second Derivative of the
+#' @description The function \code{phi0TT(Temp,D,digits =9)} returns the Second Derivative of the
 #'     Ideal-gas Part of the Dimensionless Helmholtz Energy Equation with respect to 
-#'     Temperature, for given T [K] and D [kg/m3].
+#'     Temperature, for given Temp [K] and D [kg/m3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -164,36 +164,36 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
-#' @return The Second T Derivative of Ideal-gas part of the Helmholtz Energy: phi0TT and an Error
+#' @return The Second Temp Derivative of Ideal-gas part of the Helmholtz Energy: phi0TT and an Error
 #'      Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' phi0_TT <- phi0TT(T,D)
+#' phi0_TT <- phi0TT(Temp,D)
 #' phi0_TT
 #' 
 #' @export
 #'  
-   phi0TT <- function(T,D) {
+   phi0TT <- function(Temp,D,digits=9) {
      y <- 0.
      icode <- 0
-     res <- .Fortran('phi0TTTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-     options(digits=9)
+     res <- .Fortran('phi0TTTD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
      if (res[[4]] != 0) { 
        error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
        print(error)
      }
-     return(res[[3]])
+     return(round(res[[3]],digits = digits))
    }
    
 #' Second Derivative of the Ideal-Gas Part of the Dimensionless Helmholtz Energy Equation
 #'     with respect to Density and Temperature
 #'
-#' @description The function \code{phi0DT()} returns the Second Derivative of the
+#' @description The function \code{phi0DT(digits=9)} returns the Second Derivative of the
 #'     Ideal-gas Part of the Dimensionless Helmholtz Energy Equation with respect to 
 #'     Density and Temperature.
 #'
@@ -207,29 +207,30 @@
 #' @return The Second DT Derivative of Ideal-gas Part of the Helmholtz Energy: phi0DT and an Error
 #'      Message (if an error occur: \link{errorCodes})
 #' 
+#' @param digits Digits of results (optional)
+#' 
 #' @examples
 #' phi0_DT <- phi0DT()
 #' phi0_DT
 #' 
 #' @export
 #'  
-  phi0DT <- function() {
+  phi0DT <- function(digits=9) {
      y <- 0.
      icode <- 0
      res <- .Fortran('phi0DT', as.double(y), as.integer(icode))
-     options(digits=9)
      if (res[[2]] != 0) { 
        error <-  as.character(errorCodes[which(errorCodes[,1]==res[[2]]),2])
        print(error)
      }
-     return(res[[1]])
+     return(round(res[[1]],digits = digits))
   }
    
 #' Residual-Gas Part of the Dimensionless Helmholtz Energy Equation, Function 
 #'     of Temperature and Density
 #'
-#' @description The function \code{phir(T,D)} returns the Residual-Gas Part of the Dimensionless 
-#'     Helmholtz Energy Equation for given T [K] and D [kg/m3].
+#' @description The function \code{phir(Temp,D,digits=9)} returns the Residual-Gas Part of the Dimensionless 
+#'     Helmholtz Energy Equation for given Temp [K] and D [kg/m3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -238,37 +239,37 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
 #' @return The Residual-Gas Part of the Dimensionless Helmholtz Energy Equation: phir
 #'      and an Error Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' phir_TD <- phir(T,D)
+#' phir_TD <- phir(Temp,D)
 #' phir_TD
 #' 
 #' @export
 #' 
-   phir <- function(T,D) {
+   phir <- function(Temp,D,digits=9) {
      y <- 0.
      icode <- 0
-     res <- .Fortran('phiRTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-     options(digits=9)
+     res <- .Fortran('phiRTD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
      if (res[[4]] != 0) { 
        error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
        print(error)
      }
-     return(res[[3]])
+     return(round(res[[3]],digits = digits))
    }
    
 #' First Derivative of the Residual-Gas part of the Dimensionless Helmholtz Energy Equation
 #'     with respect to Density, Function of Temperature and Density
 #' 
-#' @description The function \code{phirD(T,D)} returns the First Derivative of the 
-#'     Residual-Gas Part of the Dimensionless Helmholtz Energy Equation for given T [K] and D [kg/m3].
+#' @description The function \code{phirD(Temp,D,digits=9)} returns the First Derivative of the 
+#'     Residual-Gas Part of the Dimensionless Helmholtz Energy Equation for given Temp [K] and D [kg/m3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -277,37 +278,37 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
 #' @return The First Derivative of the Residual-Gas Part of the Dimensionless Helmholtz 
 #'     Energy Equation: phirD, and an Error Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
 #' phir_D <- phirD(T,D)
 #' phir_D
 #' 
 #' @export
 #' 
-   phirD <- function(T,D) {
+   phirD <- function(Temp,D,digits=9) {
      y <- 0.
      icode <- 0
      res <- .Fortran('phiRDTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-     options(digits=9)
      if (res[[4]] != 0) { 
        error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
        print(error)
      }
-     return(res[[3]])
+     return(round(res[[3]],digits))
    }
    
 #' Second Derivative of the Residual-Gas Part of the Dimensionless Helmholtz 
 #'     Energy Equation with respect to Density, Function of Temperature and Density
 #' 
-#' @description The function \code{phirDD(T,D)} returns the Second Derivative of the 
-#'     Residual-Gas Part of the Dimensionless Helmholtz Energy Equation for given T [K] and D [kg/m3].
+#' @description The function \code{phirDD(Temp,D,digits=9)} returns the Second Derivative of the 
+#'     Residual-Gas Part of the Dimensionless Helmholtz Energy Equation for given Temp [K] and D [kg/m3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -316,38 +317,38 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
 #' @return The Second Derivative of the Residual-Gas Part of the Dimensionless Helmholtz 
 #'     Energy Equation: phirDD, and an Error Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' phir_DD <- phirDD(T,D)
+#' phir_DD <- phirDD(Temp,D)
 #' phir_DD
 #' 
 #' @export
 #' 
-   phirDD <- function(T,D) {
+   phirDD <- function(Temp,D,digits=9) {
      y <- 0.
      icode <- 0
-     res <- .Fortran('phiRDDTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-     options(digits=9)
+     res <- .Fortran('phiRDDTD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
      if (res[[4]] != 0) { 
        error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
        print(error)
      }
-     return(res[[3]])
+     return(round(res[[3]],digits = digits))
    }
    
 #' First Derivative of the Residual-Gas Part of the Dimensionless Helmholtz Energy Equation
 #'     with respect to Temperature, Function of Temperature and Density
 #' 
-#' @description The function \code{phirT(T,D)} returns the First Derivative of the 
-#'     Residual-Gas Part of the Dimensionless Helmholtz Energy Equation with respect to T,
-#'     for given T [K] and D [kg/m3].
+#' @description The function \code{phirT(Temp,D,digits=9)} returns the First Derivative of the 
+#'     Residual-Gas Part of the Dimensionless Helmholtz Energy Equation with respect to Temp,
+#'     for given Temp [K] and D [kg/m3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -356,38 +357,38 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
 #' @return The First Derivative of the Residual-Gas Part of the Dimensionless Helmholtz 
-#'     Energy Equation with respect to T: phirT, and an Error Message (if an error occur: \link{errorCodes})
+#'     Energy Equation with respect to Temp: phirT, and an Error Message (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' phir_T <- phirT(T,D)
+#' phir_T <- phirT(Temp,D)
 #' phir_T
 #' 
 #' @export
 #' 
-  phirT <- function(T,D) {
+  phirT <- function(Temp,D,digits=9) {
      y <- 0.
      icode <- 0
-     res <- .Fortran('phiRTTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-     options(digits=9)
+     res <- .Fortran('phiRTTD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
      if (res[[4]] != 0) { 
        error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
        print(error)
      }
-     return(res[[3]])
+     return(round(res[[3]],digits = digits))
   }
    
 #' Second Derivative of the Residual-Gas Part of the Dimensionless Helmholtz Energy Equation
 #'     with respect to Temperature, Function of Temperature and Density
 #' 
-#' @description The function \code{phirTT(T,D)} returns the Second Derivative of the 
-#'     Residual-Gas Part of the Dimensionless Helmholtz Energy Equation with respect to T,
-#'     for given T [K] and D [kg/m3].
+#' @description The function \code{phirTT(Temp,D,digits=9)} returns the Second Derivative of the 
+#'     Residual-Gas Part of the Dimensionless Helmholtz Energy Equation with respect to Temp,
+#'     for given Temp [K] and D [kg/m3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -396,39 +397,39 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
 #' @return The Second Derivative of the Residual-Gas Part of the Dimensionless Helmholtz 
 #'     Energy Equation with respect to T: phirTT, and an Error Message 
 #'     (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' phir_TT <- phirTT(T,D)
+#' phir_TT <- phirTT(Temp,D)
 #' phir_TT
 #' 
 #' @export
 #' 
-  phirTT <- function(T,D) {
+  phirTT <- function(Temp,D,digits=9) {
      y <- 0.
      icode <- 0
-     res <- .Fortran('phiRTTTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-     options(digits=9)
+     res <- .Fortran('phiRTTTD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
      if (res[[4]] != 0) { 
        error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
        print(error)
      }
-     return(res[[3]])
+     return(round(res[[3]],digits = digits))
   }
   
 #' Second Derivative of the Residual-Gas Part of the Dimensionless Helmholtz Energy Equation
 #'     with respect to Density and Temperature, Function of Temperature and Density
 #' 
-#' @description The function \code{phirDT(T,D)} returns the Second Derivative of the 
-#'     Residual-Gas Part of the Dimensionless Helmholtz Energy Equation with respect to D and T,
-#'     for given T [K] and D [kg/m3].
+#' @description The function \code{phirDT(Temp,D,digits=9)} returns the Second Derivative of the 
+#'     Residual-Gas Part of the Dimensionless Helmholtz Energy Equation with respect to D and Temp,
+#'     for given Temp [K] and D [kg/m3].
 #'
 #' @details This function calls a Fortran DLL that solves the Helmholtz Energy Equation. 
 #'     in accordance with the Revised Release on the IAPWS Formulation 1995 for the 
@@ -437,30 +438,30 @@
 #'     Water and Steam,  \url{http://www.iapws.org/relguide/IAPWS-95.html}. It is valid  
 #'     from the triple point to the pressure of 1000 MPa and temperature of 1273.
 #'     
-#' @param T Temperature [ K ]
+#' @param Temp Temperature [ K ]
 #' @param D Density [ kg m-3 ]
+#' @param digits Digits of results (optional)
 #' 
 #' @return The Second Derivative of the Residual-Gas Part of the Dimensionless Helmholtz 
-#'     Energy Equation with respect to D and T: phirTT, and an Error Message 
+#'     Energy Equation with respect to D and Temp: phirTT, and an Error Message 
 #'     (if an error occur: \link{errorCodes})
 #' 
 #' @examples
-#' T <- 500.
+#' Temp <- 500.
 #' D <- 838.025
-#' phir_DT <- phirDT(T,D)
+#' phir_DT <- phirDT(Temp,D)
 #' phir_DT
 #' 
 #' @export
 #' 
-  phirDT <- function(T,D) {
+  phirDT <- function(Temp,D,digits) {
     y <- 0.
     icode <- 0
-    res <- .Fortran('phiRDTTD', as.double(T), as.double(D), as.double(y), as.integer(icode))
-    options(digits=9)
+    res <- .Fortran('phiRDTTD', as.double(Temp), as.double(D), as.double(y), as.integer(icode))
     if (res[[4]] != 0) { 
       error <-  as.character(errorCodes[which(errorCodes[,1]==res[[4]]),2])
       print(error)
     }
-    return(res[[3]])
+    return(round(res[[3]],digits = digits))
   }
   
\ No newline at end of file
